@@ -2,10 +2,11 @@ import pandas as pd
 import numpy as np
 import seaborn as sns
 import matplotlib.pyplot as plt
-from .private_func import _get_report, _get_report_composite, _get_report2
+from .private_func import _get_report, _get_report_composite, _get_report2, _get_report_composite2
 import warnings
 import datetime
 import chinese_calendar as cc
+from .ta_personal import is_trading_day, not_trading_day
 
 warnings.filterwarnings("ignore")
 
@@ -146,7 +147,7 @@ def get_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     ret = ret[valid_ind]
 
     if 'drop_holiday' in kwargs:
-        dh = indicator.index.to_series().apply(lambda d: 0.0 if all([cc.is_holiday(d + datetime.timedelta(days=i))
+        dh = indicator.index.to_series().apply(lambda d: 0.0 if all([not_trading_day(d + datetime.timedelta(days=i))
                                                                      for i in range(1, 4)]) else 1.0).to_numpy()
         indicator = indicator * dh
 
@@ -173,7 +174,9 @@ def get_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     day_pnl_long.cumsum().plot(ax=ax1, label='Only Long', c='r', ls='--')
     day_pnl_short.cumsum().plot(ax=ax1, label='Only Short', c='g', ls='--')
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
+
     if alpha:
+        print('Alpha Report: \n', _get_report2(day_pnl - day_ret))
         (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', c='y')
 
     ax1.set_title('PnL={} PoT={} Sharpe={} Calmar={} WR={:.2f} HP={:.2f}'.format(
@@ -250,7 +253,7 @@ def get_pnl_plot2(pnl, fig_return=False, **kwargs):
     return
 
 
-def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
+def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=True, **kwargs):
     """
     Multi-Assets PnL
     delta: pd.DataFrame with DatatimeIndex
@@ -277,7 +280,7 @@ def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     indicator.fillna(0, inplace=True)
 
     if 'drop_holiday' in kwargs:
-        dh = indicator.index.to_series().apply(lambda d: 0.0 if all([cc.is_holiday(d + datetime.timedelta(days=i))
+        dh = indicator.index.to_series().apply(lambda d: 0.0 if all([not_trading_day(d + datetime.timedelta(days=i))
                                                                      for i in range(1, 4)]) else 1.0).to_numpy()
         indicator = indicator.multiply(dh, axis=0)
 
@@ -316,6 +319,7 @@ def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     day_pnl_short.cumsum().plot(ax=ax1, label='Only Short', c='g', ls='--')
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
     if alpha:
+        print('Alpha Report: \n', _get_report_composite2(day_pnl - day_ret))
         (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', c='y')
 
     report_all = _get_report_composite(indicator, ret)
